Sealed

Trait Sealed 

pub trait Sealed { }
🔬This is a nightly-only experimental API. (sealed)
This trait being unreachable from outside the crate prevents outside implementations of our extension traits. This allows adding more trait methods in the future.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Sealed for f32

Allows implementations within std.

Source

impl Sealed for f64

Allows implementations within std.

Source

impl Sealed for i8

Allows implementations within std.

Source

impl Sealed for i16

Allows implementations within std.

Source

impl Sealed for i32

Allows implementations within std.

Source

impl Sealed for i64

Allows implementations within std.

Source

impl Sealed for i128

Allows implementations within std.

Source

impl Sealed for isize

Allows implementations within std.

Source

impl Sealed for u8

Allows implementations within std.

Source

impl Sealed for u16

Allows implementations within std.

Source

impl Sealed for u32

Allows implementations within std.

Source

impl Sealed for u64

Allows implementations within std.

Source

impl Sealed for u128

Allows implementations within std.

Source

impl Sealed for usize

Allows implementations within std.

Source

impl<const N: usize> Sealed for Simd<f16, N>

Source

impl<const N: usize> Sealed for Simd<f32, N>

Source

impl<const N: usize> Sealed for Simd<f64, N>