Sealed

Trait Sealed 

pub trait Sealed { }
🔬This is a nightly-only experimental API. (sealed)
This trait being unreachable from outside the crate prevents outside implementations of our extension traits. This allows adding more trait methods in the future.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Sealed for OsStr

Allows extension traits within std.

Source

impl Sealed for OsString

Allows extension traits within std.

Source

impl Sealed for DirEntry

Available on non-Hermit and not ((Fortanix and SGX, or WebAssembly and non-WASI)) and (Unix) only.

Allows extension traits within std.

Source

impl Sealed for File

1.75.0 · Source

impl Sealed for FileTimes

Source

impl Sealed for Stderr

Source

impl Sealed for StderrLock<'_>

Source

impl Sealed for Stdin

Source

impl Sealed for StdinLock<'_>

Source

impl Sealed for Stdout

Source

impl Sealed for StdoutLock<'_>

1.89.0 · Source

impl Sealed for TcpStream

Available on (Android or Cygwin or Linux) and not ((Fortanix and SGX, or WebAssembly and non-WASI)) only.
Source

impl Sealed for BorrowedFd<'_>

Available on Hermit or Motor OS or Trusty or Unix or WASI only.
Source

impl Sealed for OwnedFd

Available on Hermit or Motor OS or Trusty or Unix or WASI only.
1.70.0 · Source

impl Sealed for SocketAddr

Available on non-Hermit and not ((Fortanix and SGX, or WebAssembly and non-WASI)) and (Unix) only.
Source

impl Sealed for UnixDatagram

Available on non-Hermit and not ((Fortanix and SGX, or WebAssembly and non-WASI)) and (Unix) only.

Allows extension traits within std.

Source

impl Sealed for UnixStream

Available on non-Hermit and not ((Fortanix and SGX, or WebAssembly and non-WASI)) and (Unix) only.

Allows extension traits within std.

Source

impl Sealed for Child

Allows extension traits within std.

Source

impl Sealed for Command

Allows extension traits within std.

Source

impl Sealed for ExitCode

Allows extension traits within std.

Source

impl Sealed for ExitStatus

Allows extension traits within std.

Source

impl Sealed for ExitStatusError

Allows extension traits within std.

Source

impl<const N: usize> Sealed for Simd<f16, N>

Source

impl<const N: usize> Sealed for Simd<f32, N>

Source

impl<const N: usize> Sealed for Simd<f64, N>