Sealed

Trait Sealed 

pub trait Sealed { }
🔬This is a nightly-only experimental API. (sealed)
This trait being unreachable from outside the crate prevents outside implementations of our extension traits. This allows adding more trait methods in the future.

Implementors

Source

impl Sealed for OsStr

Allows extension traits within std.

Source

impl Sealed for OsString

Allows extension traits within std.

Source

impl Sealed for DirEntry

Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.

Allows extension traits within std.

Source

impl Sealed for File

1.75.0 · Source

impl Sealed for FileTimes

Source

impl Sealed for Stderr

Source

impl Sealed for StderrLock<'_>

Source

impl Sealed for Stdin

Source

impl Sealed for StdinLock<'_>

Source

impl Sealed for Stdout

Source

impl Sealed for StdoutLock<'_>

1.89.0 · Source

impl Sealed for TcpStream

Available on (Linux or Android or Cygwin) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Source

impl Sealed for BorrowedFd<'_>

Available on Unix or Hermit or Trusty or WASI or Motor OS only.
Source

impl Sealed for OwnedFd

Available on Unix or Hermit or Trusty or WASI or Motor OS only.
1.70.0 · Source

impl Sealed for SocketAddr

Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Source

impl Sealed for UnixDatagram

Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.

Allows extension traits within std.

Source

impl Sealed for UnixStream

Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.

Allows extension traits within std.

Source

impl Sealed for Child

Allows extension traits within std.

Source

impl Sealed for Command

Allows extension traits within std.

Source

impl Sealed for ExitCode

Allows extension traits within std.

Source

impl Sealed for ExitStatus

Allows extension traits within std.

Source

impl Sealed for ExitStatusError

Allows extension traits within std.

Source

impl<const N: usize> Sealed for Simd<f16, N>

Source

impl<const N: usize> Sealed for Simd<f32, N>

Source

impl<const N: usize> Sealed for Simd<f64, N>