pub trait Sealed { }🔬This is a nightly-only experimental API. (
sealed)Expand description
This trait being unreachable from outside the crate prevents outside implementations of our extension traits. This allows adding more trait methods in the future.
Implementors
impl Sealed for OsStr
Allows extension traits within std.
impl Sealed for OsString
Allows extension traits within std.
impl Sealed for DirEntry
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Allows extension traits within std.
impl Sealed for File
impl Sealed for FileTimes
impl Sealed for Stderr
impl Sealed for StderrLock<'_>
impl Sealed for Stdin
impl Sealed for StdinLock<'_>
impl Sealed for Stdout
impl Sealed for StdoutLock<'_>
impl Sealed for TcpStream
Available on (Linux or Android or Cygwin) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl Sealed for BorrowedFd<'_>
Available on Unix or Hermit or Trusty or WASI or Motor OS only.
impl Sealed for OwnedFd
Available on Unix or Hermit or Trusty or WASI or Motor OS only.
impl Sealed for SocketAddr
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
impl Sealed for UnixDatagram
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Allows extension traits within std.
impl Sealed for UnixStream
Available on non-Hermit and (Unix) and not ((WebAssembly and non-WASI, or Fortanix and SGX)) only.
Allows extension traits within std.
impl Sealed for Child
Allows extension traits within std.
impl Sealed for Command
Allows extension traits within std.
impl Sealed for ExitCode
Allows extension traits within std.
impl Sealed for ExitStatus
Allows extension traits within std.
impl Sealed for ExitStatusError
Allows extension traits within std.